@@ -175,14 +175,16 @@ static void mgets(WIN *w, int x, int y, char *s, int len, int maxl)
  * Read in a string, but first check to see if it's
  * allowed to do so.
  */
-static void pgets(WIN *w, int x, int y, char *s, int len, unsigned int maxl)
+static void pgets(WIN *w, int x, int y, char *s, int len, unsigned int maxl,
+                  int extend_tilde)
 {
   struct pars *p = (struct pars *)s;
   char *home = NULL;
 
   mc_wlocate(w, x, y);
   mc_wgets(w, s, len, maxl);
-  if (s[0] == '~' && (s[1] == '/' || s[1] == 0) &&
+  if (extend_tilde &&
+      s[0] == '~' && (s[1] == '/' || s[1] == 0) &&
       (home = getenv("HOME")) && strlen(s) + strlen(home) <= maxl) {
     int i = 0;
     memmove(s + strlen(home), s + 1, strlen(s));
@@ -263,7 +265,7 @@ static void dologopt(void)
         return;
       case 'A':
         pgets(w, mbslen(logfnstr) + 1, 0,
-              P_LOGFNAME, PARS_VAL_LEN, PARS_VAL_LEN);
+              P_LOGFNAME, PARS_VAL_LEN, PARS_VAL_LEN, 1);
         strcpy(logfname,P_LOGFNAME);
         break;
       case 'B':
@@ -321,21 +323,21 @@ static void dopath(void)
         mc_wclose(w, 1);
         return;
       case 'A':
-        pgets(w, mbslen (download_directory) + 1, 0, P_DOWNDIR, 64, 64);
+        pgets(w, mbslen (download_directory) + 1, 0, P_DOWNDIR, 64, 64, 1);
         init_dir('d');
         break;
       case 'B':
-        pgets(w, mbslen (upload_directory) + 1, 1, P_UPDIR, 64, 64);
+        pgets(w, mbslen (upload_directory) + 1, 1, P_UPDIR, 64, 64, 1);
         init_dir('u');
         break;
       case 'C':
-        pgets(w, mbslen (script_directory) + 1, 2, P_SCRIPTDIR, 64, 64);
+        pgets(w, mbslen (script_directory) + 1, 2, P_SCRIPTDIR, 64, 64, 1);
         break;
       case 'D':
-        pgets(w, mbslen (script_program) + 1, 3, P_SCRIPTPROG, 64, 64);
+        pgets(w, mbslen (script_program) + 1, 3, P_SCRIPTPROG, 64, 64, 1);
         break;
       case 'E':
-        pgets(w, mbslen (kermit_program) + 1, 4, P_KERMIT, 64, 64);
+        pgets(w, mbslen (kermit_program) + 1, 4, P_KERMIT, 64, 64, 1);
         break;
 #ifdef LOGFILE
       case 'F':
@@ -373,7 +375,7 @@ static void inputproto(WIN *w, int n)
   }
   mc_wlocate(w, 4, n + 1);
   mc_wgets(w, P_PNAME(n), 10, 64);
-  pgets(w, 15, n+1, P_PPROG(n), 31, 64);
+  pgets(w, 15, n+1, P_PPROG(n), 31, 64, 0);
   do {
     mc_wlocate(w, 47, n + 1);
     mc_wprintf(w, "%c", P_PNN(n));
@@ -543,7 +545,11 @@ static void doserial(void)
 
   w = mc_wopen(5, 4, 75, 12, BDOUBLE, stdattr, mfcolor, mbcolor, 0, 0, 1);
   mc_wprintf(w, "%s %.41s\n", serial_device, P_PORT);
+#if !HAVE_LOCKDEV
   mc_wprintf(w, "%s %.41s\n", lockfile_location, P_LOCK);
+#else
+  mc_wprintf(w, "\n");
+#endif
   mc_wprintf(w, "%s %.41s\n", callin_program, P_CALLIN);
   mc_wprintf(w, "%s %.41s\n", callout_program, P_CALLOUT);
   mc_wprintf(w, "%s %s %s%s%s\n",
@@ -561,26 +567,26 @@ static void doserial(void)
         mc_wclose(w, 1);
         return;
       case 'A':
-        pgets(w, mbslen (serial_device) + 1, 0, P_PORT, 64, 64);
+        pgets(w, mbslen (serial_device) + 1, 0, P_PORT, 64, 64, 1);
         break;
+#if !HAVE_LOCKDEV
       case 'B':
-        pgets(w, mbslen (lockfile_location) + 1, 1, P_LOCK, 64, 64);
+        pgets(w, mbslen (lockfile_location) + 1, 1, P_LOCK, 64, 64, 1);
         break;
+#endif
       case 'C':
-        pgets(w, mbslen (callin_program) + 1, 2, P_CALLIN, 64, 64);
+        pgets(w, mbslen (callin_program) + 1, 2, P_CALLIN, 64, 64, 1);
         break;
       case 'D':
-        pgets(w, mbslen (callout_program) + 1, 3, P_CALLOUT, 64, 64);
+        pgets(w, mbslen (callout_program) + 1, 3, P_CALLOUT, 64, 64, 1);
         break;
       case 'E':
         get_bbp(P_BAUDRATE, P_BITS, P_PARITY, P_STOPB, 0);
         if (portfd >= 0)
           port_init();
         mc_wlocate(w, mbslen (bps_par_bits) + 1, 4);
-        mc_wprintf(w, "%s %s%s%s  \n",
-                P_BAUDRATE, P_BITS, P_PARITY, P_STOPB);
-        if (st)
-          mode_status();
+        mc_wprintf(w, "%s %s%s%s  \n", P_BAUDRATE, P_BITS, P_PARITY, P_STOPB);
+        show_status();
         markch(P_BAUDRATE);
         markch(P_BITS);
         markch(P_PARITY);
@@ -621,27 +627,33 @@ static void domodem(void)
   WIN *w;
   char *str;
   int c, x, y, ypos, maxl, string_size;
-  char *init_string         = _(" A - Init string .........");
-  char *reset_string        = _(" B - Reset string ........");
-  char *dialing_prefix_1    = _(" C - Dialing prefix #1....");
-  char *dialing_suffix_1    = _(" D - Dialing suffix #1....");
-  char *dialing_prefix_2    = _(" E - Dialing prefix #2....");
-  char *dialing_suffix_2    = _(" F - Dialing suffix #2....");
-  char *dialing_prefix_3    = _(" G - Dialing prefix #3....");
-  char *dialing_suffix_3    = _(" H - Dialing suffix #3....");
-  char *connect_string      = _(" I - Connect string ......");
-  char *no_connect_strings  = _(" J - No connect strings ..");
-  char *hangup_string       = _(" K - Hang-up string ......");
-  char *dial_cancel_string  = _(" L - Dial cancel string ..");
-  char *dial_time           = _(" M - Dial time ...........");
-  char *delay_before_redial = _(" N - Delay before redial .");
-  char *number_of_tries     = _(" O - Number of tries .....");
-  char *dtr_drop_time       = _(" P - DTR drop time (0=no).");
-  char *auto_bps_detect     = _(" Q - Auto bps detect .....");
-  char *modem_has_dcd_line  = _(" R - Modem has DCD line ..");
-  char *shown_speed         = _(" S - Status line shows ...");
-  char *multi_node          = _(" T - Multi-line untag ....");
-  char *question            = _("Change which setting?");
+  const char *init_string         = _(" A - Init string .........");
+  const char *reset_string        = _(" B - Reset string ........");
+  const char *dialing_prefix_1    = _(" C - Dialing prefix #1....");
+  const char *dialing_suffix_1    = _(" D - Dialing suffix #1....");
+  const char *dialing_prefix_2    = _(" E - Dialing prefix #2....");
+  const char *dialing_suffix_2    = _(" F - Dialing suffix #2....");
+  const char *dialing_prefix_3    = _(" G - Dialing prefix #3....");
+  const char *dialing_suffix_3    = _(" H - Dialing suffix #3....");
+  const char *connect_string      = _(" I - Connect string ......");
+  const char *no_connect_strings  = _(" J - No connect strings ..");
+  const char *hangup_string       = _(" K - Hang-up string ......");
+  const char *dial_cancel_string  = _(" L - Dial cancel string ..");
+  const char *dial_time           = _(" M - Dial time ...........");
+  const char *delay_before_redial = _(" N - Delay before redial .");
+  const char *number_of_tries     = _(" O - Number of tries .....");
+  const char *dtr_drop_time       = _(" P - DTR drop time (0=no).");
+  const char *auto_bps_detect     = _(" Q - Auto bps detect .....");
+  const char *modem_has_dcd_line  = _(" R - Modem has DCD line ..");
+  const char *shown_speed         = _(" S - Status line shows ...");
+  const char *multi_node          = _(" T - Multi-line untag ....");
+  const char *question            = _("Change which setting?");
+
+  const char *defaults[] =
+    {
+      "~^M~AT S7=45 S0=0 L1 V1 X4 &c1 E1 Q0^M",
+      "^M~ATZ^M~",
+    };
 
   w = mc_wopen(2, 2, 77, 22, BDOUBLE, stdattr, mfcolor, mbcolor, 0, 0, 1);
 
@@ -679,7 +691,7 @@ static void domodem(void)
   mc_wlocate(w, 1, 20);
   mc_wprintf(w, "%s ", question);
   x = w->curx; y = w->cury;
-  mc_wprintf(w, _("      (Return or Esc to exit)"));
+  mc_wprintf(w, _("    Return or Esc to exit. Edit A+B to get defaults."));
   mc_wredraw(w, 1);
 
   while (1) {
@@ -740,17 +752,35 @@ static void domodem(void)
         if (string_size == 0)
           string_size = mbslen(connect_string);
 
-        /* Calculate adress of string tomodify */
-        str = P_MINIT + (c - 'A') * sizeof(struct pars);
-        pgets(w, string_size + 1, ypos + (c - 'A'), str, maxl, maxl);
+	{
+	  int loc = c - 'A';
+
+	  /* Calculate adress of string to modify */
+	  str = P_MINIT + loc * sizeof(struct pars);
+
+	  /* Nowadays (2011), the modem init and reset strings are seldomly
+	   * used, so we initialize those values to an empty string and
+	   * offer the default value when trying to set those strings from
+	   * an empty value */
+	  if ((loc == 0 || loc == 1) && !*str)
+	    {
+	      strncpy(str, defaults[loc], PARS_VAL_LEN);
+	      str[PARS_VAL_LEN - 1] = 0;
+
+              mc_wlocate(w, string_size + 1, 1 + loc);
+              mc_wprintf(w, "%.48s\n", str);
+	    }
+
+	  pgets(w, string_size + 1, ypos + loc, str, maxl, maxl, 0);
+	}
         break;
       case 'J':
         string_size = mbslen (no_connect_strings);
         /* Walk through all four */
-        pgets(w, string_size + 1, 10, P_MNOCON1, 20, 64);
-        pgets(w, string_size + 1 + 22, 10, P_MNOCON2, 20, 64);
-        pgets(w, string_size + 1 , 11, P_MNOCON3, 20, 64);
-        pgets(w, string_size + 1 + 22, 11, P_MNOCON4, 20, 64);
+        pgets(w, string_size + 1, 10, P_MNOCON1, 20, 64, 0);
+        pgets(w, string_size + 1 + 22, 10, P_MNOCON2, 20, 64, 0);
+        pgets(w, string_size + 1 , 11, P_MNOCON3, 20, 64, 0);
+        pgets(w, string_size + 1 + 22, 11, P_MNOCON4, 20, 64, 0);
         break;
       case 'Q':
         psets(P_MAUTOBAUD, yesno(P_MAUTOBAUD[0] == 'N'));
@@ -766,7 +796,7 @@ static void domodem(void)
         psets(P_SHOWSPD, P_SHOWSPD[0] == 'd' ? "l": "d");
         mc_wlocate(w, 35 + mbslen (shown_speed), 17);
         mc_wputs(w, sspd(P_SHOWSPD));
-        mode_status();
+        show_status();
         break;
       case 'T': /* Update for multi-node */
         psets(P_MULTILINE, yesno(P_MULTILINE[0] == 'N' ));
@@ -796,7 +826,7 @@ static void doscrkeyb(void)
   int clr = 1;
   int tmp_c;    /* fmg - need it to color keep in sanity checks */
   char buf[16];
-  int miny = 2, maxy = 20;
+  int miny = 2, maxy = 22;
   int old_stat = P_STATLINE[0];
   FILE *fp;
   char *command_key           = _(" A - Command key is         :");
@@ -815,13 +845,16 @@ static void doscrkeyb(void)
   char *character_conversion  = _(" O - Character conversion   :");
   char *add_linefeed          = _(" P - Add linefeed           :");
   char *local_echo_str        = _(" Q - Local echo             :");
+  char *line_wrap             = _(" R - Line Wrap              :");
+  char *display_hex_str       = _(" S - Hex Display            :");
+  char *add_carriagereturn    = _(" T - Add carriage return    :");
   char *question              = _("Change which setting?  (Esc to exit)");
 
   w = mc_wopen(15, miny, 69, maxy, BDOUBLE, stdattr, mfcolor, mbcolor, 0, 0, 1);
 
   mc_wtitle(w, TMID, _("Screen and keyboard"));
 
-  mc_wprintf(w, "\n%s %s\n", command_key, P_ESCAPE);
+  mc_wprintf(w, "%s %s\n", command_key, P_ESCAPE);
   mc_wprintf(w, "%s %s\n", backspace_key, P_BACKSPACE);
   mc_wprintf(w, "%s %s\n", status_line, _(P_STATLINE));
   mc_wprintf(w, "%s %s\n", alarm_sound, _(P_SOUND));
@@ -844,6 +877,9 @@ static void doscrkeyb(void)
 
   mc_wprintf(w, "%s %s\n", add_linefeed, _(P_ADDLINEFEED));
   mc_wprintf(w, "%s %s\n", local_echo_str, _(P_LOCALECHO));
+  mc_wprintf(w, "%s %s\n", line_wrap, _(P_LINEWRAP));
+  mc_wprintf(w, "%s %s\n", display_hex_str, _(P_DISPLAYHEX));
+  mc_wprintf(w, "%s %s\n", add_carriagereturn, _(P_ADDCARRIAGERETURN));
 
   mc_wredraw(w, 1);
 
@@ -931,7 +967,7 @@ static void doscrkeyb(void)
         else
           sprintf(buf, "^%c           ", (c & 0x1f) + 'A' - 1);
         psets(P_ESCAPE, buf);
-        mc_wlocate(w, mbslen (command_key) + 1, 1);
+        mc_wlocate(w, mbslen (command_key) + 1, 0);
         mc_wputs(w, _(buf));
         clr = 1;
         alt_override = 0;
@@ -947,15 +983,14 @@ static void doscrkeyb(void)
             break;
         }
         keyboard(KSETESC, c);
-        if (st)
-          show_status();
+        show_status();
         break;
       case 'B':
         if (P_BACKSPACE[0] == 'D')
           psets(P_BACKSPACE, "BS");
         else
           psets(P_BACKSPACE, "DEL");
-        mc_wlocate(w, mbslen (backspace_key) + 1, 2);
+        mc_wlocate(w, mbslen (backspace_key) + 1, 1);
         mc_wprintf(w, "%s ", P_BACKSPACE);
         keyboard(KSETBS, P_BACKSPACE[0] == 'B' ? 8 : 127);
         break;
@@ -969,12 +1004,12 @@ static void doscrkeyb(void)
           if (LINES > 24)
             tempst = 0;
         }
-        mc_wlocate(w, mbslen (status_line) + 1, 3);
+        mc_wlocate(w, mbslen (status_line) + 1, 2);
         mc_wprintf(w, "%s ", _(P_STATLINE));
         break;
       case 'D':
         psets(P_SOUND, yesno(P_SOUND[0] == 'N'));
-        mc_wlocate(w, mbslen (alarm_sound) + 1, 4);
+        mc_wlocate(w, mbslen (alarm_sound) + 1, 3);
         mc_wprintf(w, "%s", _(P_SOUND));
         break;
       case 'E': /* fmg - letters cycle colors */
@@ -983,7 +1018,7 @@ static void doscrkeyb(void)
         else
           mfcolor++;
         psets(P_MFG, J_col[mfcolor]);
-        mc_wlocate(w, mbslen (foreground_color_menu) + 1, 5);
+        mc_wlocate(w, mbslen (foreground_color_menu) + 1, 4);
         mc_wprintf(w, "%s   ", _(J_col[mfcolor]));
         break;
       case 'F': /* fmg - letters cycle colors */
@@ -992,7 +1027,7 @@ static void doscrkeyb(void)
         else
           mbcolor++;
         psets(P_MBG, J_col[mbcolor]);
-        mc_wlocate(w, mbslen (background_color_menu) + 1, 6);
+        mc_wlocate(w, mbslen (background_color_menu) + 1, 5);
         mc_wprintf(w, "%s   ", _(J_col[mbcolor]));
         break;
       case 'G': /* fmg - letters cycle colors */
@@ -1001,7 +1036,7 @@ static void doscrkeyb(void)
         else
           tfcolor++;
         psets(P_TFG, J_col[tfcolor]);
-        mc_wlocate(w, mbslen (foreground_color_term) + 1, 7);
+        mc_wlocate(w, mbslen (foreground_color_term) + 1, 6);
         mc_wprintf(w, "%s   ", _(J_col[tfcolor]));
         if (us)
           vt_pinit(us, tfcolor, tbcolor);
@@ -1012,7 +1047,7 @@ static void doscrkeyb(void)
         else
           tbcolor++;
         psets(P_TBG, J_col[tbcolor]);
-        mc_wlocate(w, mbslen (background_color_term) + 1, 8);
+        mc_wlocate(w, mbslen (background_color_term) + 1, 7);
         mc_wprintf(w, "%s   ", _(J_col[tbcolor]));
         if (us)
           vt_pinit(us, tfcolor, tbcolor);
@@ -1033,7 +1068,7 @@ static void doscrkeyb(void)
           show_status();
         }
         psets(P_SFG, J_col[sfcolor]);
-        mc_wlocate(w, mbslen (foreground_color_stat) + 1, 9);
+        mc_wlocate(w, mbslen (foreground_color_stat) + 1, 8);
         mc_wprintf(w, "%s   ", _(J_col[sfcolor]));
         break;
       case 'J': /* fmg - letters cycle colors & redraw stat line */
@@ -1052,12 +1087,12 @@ static void doscrkeyb(void)
           show_status();
         }
         psets(P_SBG, J_col[sbcolor]);
-        mc_wlocate(w, mbslen (background_color_stat) + 1, 10);
+        mc_wlocate(w, mbslen (background_color_stat) + 1, 9);
         mc_wprintf(w, "%s   ", _(J_col[sbcolor]));
         break;
       case 'K': /* MARK updated 02/17/95 - Config history size */
-        pgets(w, mbslen (history_buffer_size) + 1, 11,
-              P_HISTSIZE, 6, 6);
+        pgets(w, mbslen (history_buffer_size) + 1, 10,
+              P_HISTSIZE, 6, 6, 0);
 
         /* In case gibberish or a value was out of bounds, */
         /* limit history buffer size between 0 to 5000 lines */
@@ -1068,11 +1103,11 @@ static void doscrkeyb(void)
         else if (atoi(P_HISTSIZE) >= 5000)
           strcpy(P_HISTSIZE,"5000");
 
-        mc_wlocate(w, mbslen (history_buffer_size) + 1, 11);
+        mc_wlocate(w, mbslen (history_buffer_size) + 1, 10);
         mc_wprintf(w, "%s     ", P_HISTSIZE);
         break;
       case 'L': /* fmg - get local macros storage file */
-        pgets(w, mbslen (macros_file) + 1, 12, P_MACROS, 64, 64);
+        pgets(w, mbslen (macros_file) + 1, 11, P_MACROS, 64, 64, 1);
 
         /* Try to open the file to read it in. */
         fp = fopen(pfix_home(P_MACROS), "r+");
@@ -1100,24 +1135,40 @@ static void doscrkeyb(void)
         break;
       case 'N':
         psets(P_MACENAB, yesno(P_MACENAB[0] == 'N'));
-        mc_wlocate(w, mbslen (macros_enabled) + 1, 14);
+        mc_wlocate(w, mbslen (macros_enabled) + 1, 13);
         mc_wprintf(w, "%s", _(P_MACENAB));
         break;
       case 'O': /* Character conversions - jl / 04.09.97 */
         doconv();
-        mc_wlocate(w, mbslen (character_conversion) + 1, 15);
+        mc_wlocate(w, mbslen (character_conversion) + 1, 14);
         mc_wprintf(w, "%-16.16s", _(P_CONVF));
         break;
       case 'P':
         psets(P_ADDLINEFEED, yesno(P_ADDLINEFEED[0] == 'N'));
-        mc_wlocate(w, mbslen (add_linefeed) + 1, 16);
+        mc_wlocate(w, mbslen (add_linefeed) + 1, 15);
         mc_wprintf(w, "%s", _(P_ADDLINEFEED));
         break;
       case 'Q':
         psets(P_LOCALECHO, yesno(P_LOCALECHO[0] == 'N'));
-        mc_wlocate(w, mbslen (local_echo_str) + 1, 17);
+        mc_wlocate(w, mbslen (local_echo_str) + 1, 16);
         mc_wprintf(w, "%s", _(P_LOCALECHO));
         break;
+      case 'R':
+        psets(P_LINEWRAP, yesno(P_LINEWRAP[0] == 'N'));
+        mc_wlocate(w, mbslen (line_wrap) + 1, 17);
+        mc_wprintf(w, "%s", _(P_LINEWRAP));
+        break;
+      case 'S':
+	psets(P_DISPLAYHEX, yesno(P_DISPLAYHEX[0] == 'N'));
+	mc_wlocate(w, mbslen(display_hex_str) + 1, 18);
+	mc_wprintf(w, "%s", _(P_DISPLAYHEX));
+	display_hex = strcasecmp(P_DISPLAYHEX, "yes") == 0;
+	break;
+      case 'T':
+        psets(P_ADDCARRIAGERETURN, yesno(P_ADDCARRIAGERETURN[0] == 'N'));
+        mc_wlocate(w, mbslen (add_carriagereturn) + 1, 19);
+        mc_wprintf(w, "%s", _(P_ADDCARRIAGERETURN));
+        break;
      }
   }
 }
@@ -1134,11 +1185,12 @@ int dotermmenu(void)
   int new_term = -1;
   int old_stat = P_STATLINE[0];
   char buf[8];
-  char *terminal_emulation  = _(" A - Terminal emulation  :");
-  char *backspace_key_sends = _(" B - Backspace key sends :");
-  char *status_line         = _(" C -      Status line is :");
-  char *msg_nl_delay        = _(" D -  Newline delay (ms) :");
-  char *msg_answerback      = _(" E -      ENQ answerback :");
+  char *terminal_emulation  = _(" A -      Terminal emulation :");
+  char *backspace_key_sends = _(" B -     Backspace key sends :");
+  char *status_line         = _(" C -          Status line is :");
+  char *msg_nl_delay        = _(" D -   Newline tx delay (ms) :");
+  char *msg_answerback      = _(" E -          ENQ answerback :");
+  char *msg_ch_delay        = _(" F - Character tx delay (ms) :");
   char *question            = _("Change which setting?");
 
   w = mc_wopen(15, 7, 64, 15, BDOUBLE, stdattr, mfcolor, mbcolor, 0, 0, 1);
@@ -1149,6 +1201,7 @@ int dotermmenu(void)
   mc_wprintf(w, "%s %s\n", status_line, _(P_STATLINE));
   mc_wprintf(w, "%s %d\n", msg_nl_delay, vt_nl_delay);
   mc_wprintf(w, "%s %s\n", msg_answerback, P_ANSWERBACK);
+  mc_wprintf(w, "%s %d\n", msg_ch_delay, vt_ch_delay);
   mc_wlocate(w, 4, 7);
   mc_wputs(w, question);
 
@@ -1204,14 +1257,22 @@ int dotermmenu(void)
         break;
       case 'D':
         sprintf(buf, "%d", vt_nl_delay);
-        mc_wlocate(w, mbslen(msg_nl_delay) +1, 4);
+        mc_wlocate(w, mbslen(msg_nl_delay) + 1, 4);
         mc_wgets(w, buf, 5, 5);
         vt_nl_delay = atoi(buf);
-        mc_wlocate(w, mbslen(msg_nl_delay) +1, 4);
+        mc_wlocate(w, mbslen(msg_nl_delay) + 1, 4);
         mc_wprintf(w, "%-4d", vt_nl_delay);
         break;
       case 'E':
-        pgets(w, strlen(msg_answerback) + 1, 5, P_ANSWERBACK, 50, 50);
+        pgets(w, strlen(msg_answerback) + 1, 5, P_ANSWERBACK, 50, 50, 0);
+        break;
+      case 'F':
+        sprintf(buf, "%d", vt_ch_delay);
+        mc_wlocate(w, mbslen(msg_ch_delay) + 1, 6);
+        mc_wgets(w, buf, 5, 5);
+        vt_ch_delay = atoi(buf);
+        mc_wlocate(w, mbslen(msg_ch_delay) + 1, 6);
+        mc_wprintf(w, "%-4d", vt_ch_delay);
         break;
       default:
         break;
@@ -1718,7 +1779,7 @@ void doconv(void)
         strcpy(buf,P_CONVF);
         prompt=_("Load file: %s");
         mc_wprintf(w, prompt, buf);
-        pgets(w, mbslen(prompt) - 1, ymax - 1, P_CONVF, 64, 64);
+        pgets(w, mbslen(prompt) - 1, ymax - 1, P_CONVF, 64, 64, 1);
         if (loadconv(P_CONVF) == 0) {
           if (strcmp(P_CONVF,buf))
             markch(P_CONVF);
@@ -1730,7 +1791,7 @@ void doconv(void)
         strcpy(buf,P_CONVF);
         prompt=_("Save as file: %s");
         mc_wprintf(w, prompt, buf);
-        pgets(w, mbslen(prompt) - 1, ymax - 1, P_CONVF, 64, 64);
+        pgets(w, mbslen(prompt) - 1, ymax - 1, P_CONVF, 64, 64, 1);
         if (saveconv(P_CONVF) == 0) {
           if (strcmp(P_CONVF,buf))
             markch(P_CONVF);
@@ -1806,8 +1867,12 @@ int loadconv(char *buf)
     werror(_("Cannot open conversion table %s"), pfix_home(buf));
     return 1;
   }
-  fread(vt_inmap, sizeof(vt_inmap), (size_t)1, fp);
-  fread(vt_outmap, sizeof(vt_outmap), (size_t)1, fp);
+  if (   fread(vt_inmap, sizeof(vt_inmap), (size_t)1, fp) != 1
+      || fread(vt_outmap, sizeof(vt_outmap), (size_t)1, fp) != 1)
+    {
+      werror(_("Cannot read conversion table %s"), pfix_home(buf));
+      return 1;
+    }
   fclose(fp);
   return 0;
 }
