@@ -117,8 +117,8 @@ struct pars mpars[] = {
   /* The script program */
   { "runscript",	0,   "scriptprog" },
   /* Modem parameters */
-  { "~^M~AT S7=45 S0=0 L1 V1 X4 &c1 E1 Q0^M",   0,   "minit" },
-  { "^M~ATZ^M~",	0,   "mreset" },
+  { "",                 0,   "minit" },
+  { "",                 0,   "mreset" },
   { "ATDT",		0,   "mdialpre" },
   { "^M",		0,   "mdialsuf" },
   { "ATDP",		0,   "mdialpre2" },
@@ -192,6 +192,9 @@ struct pars mpars[] = {
   /* Terminal behaviour */
   { "No",		0,    "localecho" },
   { "No",		0,    "addlinefeed" },
+  { "No",		0,    "linewrap" },
+  { "No",		0,    "displayhex" },
+  { "No",		0,    "addcarreturn" },
 
   { "Minicom"VERSION,   0,    "answerback" },
 
