@@ -5,7 +5,7 @@
  *		included. This file is only included from sysdep[12].c
  *		anyway!
  *
- *		$Id: sysdep.h,v 1.4 2007-10-10 20:18:20 al-guest Exp $
+ *		$Id: sysdep.h,v 1.6 2008-03-21 20:27:56 al-guest Exp $
  *
  *		This file is part of the minicom communications package,
  *		Copyright 1991-1995 Miquel van Smoorenburg.
@@ -48,16 +48,9 @@
 #    endif
 #  endif
 #endif
-/* Some system-specific include files for modem control. */
-#ifdef _HPUX_SOURCE
-#  include <sys/modem.h>
-#endif
 #ifdef HAVE_SYS_IOCTL_H 
 #  include <sys/ioctl.h>
 #endif
-#ifdef _DGUX_SOURCE
-#  include <sys/termiox.h>
-#endif
 
 /* And more "standard" include files. */
 #include <stdio.h>
