@@ -33,18 +33,12 @@
 #include <config.h>
 #endif
 
-#include "rcsid.h"
-RCSID("$Id: sysdep1.c,v 1.8 2007-10-10 20:18:20 al-guest Exp $")
-
 #include "sysdep.h"
 #include "minicom.h"
 
 /* Set hardware flow control. */
 void m_sethwf(int fd, int on)
 {
-#ifdef _DGUX_SOURCE
-  struct termiox x;
-#endif
 #ifdef POSIX_TERMIOS
   struct termios tty;
 #endif
@@ -62,23 +56,10 @@ void m_sethwf(int fd, int on)
     tty.c_cflag &= ~CRTSCTS;
   tcsetattr(fd, TCSANOW, &tty);
 #endif
-
-#ifdef _DGUX_SOURCE
-  if (ioctl(fd, TCGETX, &x) < 0) {
-    fprintf(stderr, _("can't get termiox attr.\n"));
-    return;
-  }
-  x.x_hflag = on ? RTSXOFF|CTSXON : 0;
-
-  if (ioctl(fd, TCSETX, &x) < 0) {
-    fprintf(stderr, _("can't set termiox attr.\n"));
-    return;
-  }
-#endif
 }
 
 /* Set RTS line. Sometimes dropped. Linux specific? */
-void m_setrts(int fd)
+static void m_setrts(int fd)
 {
 #ifdef USE_SOCKET
   if (portfd_is_socket)
@@ -93,9 +74,6 @@ void m_setrts(int fd)
     ioctl(fd, TIOCMODS, &mcs);
   }
 #endif
-#ifdef _COHERENT
-  ioctl(fd, TIOCSRTS, 0);
-#endif
 }
 
 /*
@@ -117,7 +95,7 @@ void m_dtrtoggle(int fd, int sec)
     }
 
 #else /* TIOCSDTR */
-#  if defined (POSIX_TERMIOS) && !defined(_HPUX_SOURCE)
+#  if defined (POSIX_TERMIOS)
 
     /* Posix - set baudrate to 0 and back */
     struct termios tty, old;
@@ -149,17 +127,6 @@ void m_dtrtoggle(int fd, int sec)
     }
 
 #    endif /* _V7 */
-#    ifdef _HPUX_SOURCE
-    unsigned long mflag = 0L;
-
-    ioctl(fd, MCSETAF, &mflag);
-    ioctl(fd, MCGETA, &mflag);
-    mflag = MRTS | MDTR;
-    if (sec > 0) {
-      sleep(sec);
-      ioctl(fd, MCSETAF, &mflag);
-    }
-#    endif /* _HPUX_SOURCE */
 #  endif /* POSIX */
 #endif /* TIOCSDTR */
   }
@@ -316,9 +283,6 @@ void m_nohang(int fd)
     lsw |= LNOHANG;
     ioctl(fd, TIOCLSET, &lsw);
 #  endif
-#  ifdef _COHERENT
-    /* Doesn't know about this either, me thinks. */
-#  endif
 #endif
   }
 }
